@@ -18,7 +18,7 @@
   
 ## Class Global Values ############################ 
   our @ISA = qw(Exporter);
-  our $VERSION = '2.0.9';
+  our $VERSION = '2.2.1';
   our $errstr = ();
   our @EXPORT_OK = ($VERSION, $errstr);
 
@@ -45,6 +45,9 @@
      }
     #add in anything which might have been sent in
      foreach (keys %p){ $obj->{$_} = $p{$_}; }
+    #default values
+     $obj->{'LongReadLen'} = 15000 unless (exists($obj->{'LongReadLen'}));
+     $obj->{'LongTruncOk'} = 0 unless (exists($obj->{'LongTruncOk'}));
     #login to database
      unless ($obj->Login()){
          $errstr = $obj->{errstr};
@@ -66,6 +69,10 @@
     #require appropriate dbi module
      my $mod = "DBD\::$self->{DBType}";
      eval "require $mod";
+     if ($@){
+         $self->{'errstr'} = "Login: failed to load DBD module $mod: $@";
+         return (undef);
+     }
     #wow, a "connection string" ... 
      if ($self->{DBType} eq "Sybase"){
          $connect_str = "dbi:Sybase:server=$self->{Server}";
@@ -93,8 +100,8 @@
          return (undef);
      }
     #go ahead and set LongReadLen and LongTruncOk
-     $self->{dbh}->{LongReadLen} = 15000;
-     $self->{dbh}->{LongTruncOk} = 0;
+     $self->{dbh}->{'LongReadLen'} = $self->{'LongReadLen'};
+     $self->{dbh}->{'LongTruncOk'} = $self->{'LongTruncOk'};
     #it's all good baby bay bay ...
      return (1);
  }
@@ -242,3 +249,35 @@ sub Insert {
     #well it must be all-good
      return (1);
 }
+
+
+## Do #############################################
+## prepare and execute an SQL statement of no
+## particular type. If errors are encountered undef is
+## returned and errors go on $obj->{errstr} as usual
+## if successfull, whatever is returned from dbi->execute
+## is returned here
+sub Do {
+    #local vars
+     my ($self, %p) = @_;
+    #required options
+     unless (exists($p{SQL})){
+         $self->{'errstr'} = "[Do]: SQL is a required option to Do";
+         return (undef);
+     }
+    #prepare statement
+     warn ("[Do]: (prepare): $p{SQL}") if $self->{'Debug'};
+     $sth = $self->{dbh}->prepare($p{SQL}) || do {
+         $self->{'errstr'} = "[Do]: failed to prepare SQL ($p{SQL}): $DBI::errstr";
+         warn ($self->{'errstr'}) if $self->{'Debug'};
+         return (undef);
+     };
+     warn ("[Do]: (executing)") if $self->{'Debug'};
+     my $res = $sth->execute() || do {
+         $self->{'errstr'} = "[Do]: failed to execute SQL ($p{SQL}): $DBI::errstr";
+         warn ($self->{'errstr'}) if $self->{'Debug'};
+         return (undef);
+     };
+     $sth->finish();
+     return ($res);
+}
